cis_config: ply_t Struct Reference

cis_config

Public Attributes | List of all members
ply_t Struct Reference

Ply structure. More...

`#include <PlySerialize.h>`

## Public Attributes
int | nvert
| Number of vertices.
int | nface
| Number faces.
float ** | vertices
| X, Y, Z positions of vertices.
int ** | faces
| Indices of the vertices composing each face.
int ** | vertex_colors
| RGB colors of each vertex.
int * | nvert_in_face
| Number of vertices in each face.

## Detailed Description

Ply structure.

The documentation for this struct was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/serialize/PlySerialize.h